@@ -14,7 +14,7 @@ use std::{env, fmt};
 use ansi_term::Colour;
 use cargo::core::compiler::{DefaultExecutor, Executor, RustcTargetData, Unit};
 use cargo::core::resolver::{HasDevUnits, ResolveOpts};
-use cargo::core::resolver::features::{ForceAllTargets, RequestedFeatures};
+use cargo::core::resolver::features::{ForceAllTargets, RequestedFeatures, CliFeatures};
 use cargo::core::manifest::Target;
 use cargo::core::package_id::PackageId;
 use cargo::core::shell::Shell;
@@ -22,7 +22,7 @@ use cargo::core::{dependency, Package, Resolve, Workspace};
 use cargo::ops::Packages;
 use cargo::util::command_prelude::{ArgMatchesExt, CompileMode, ProfileChecking};
 use cargo::util::interning::InternedString;
-use cargo::util::process_builder::ProcessBuilder;
+use cargo_util::ProcessBuilder;
 use cargo::{CargoResult, CliError, CliResult, Config};
 use serde::{Deserialize, Serialize};
 use structopt::StructOpt;
@@ -274,20 +274,16 @@ impl OptUdeps {
 		let requested_kinds = &compile_opts.build_config.requested_kinds;
 		let target_data = RustcTargetData::new(&ws, requested_kinds)?;
 
-		let req = RequestedFeatures::from_command_line(
+		let cli_features = CliFeatures::from_command_line(
 			&self.features,
 			self.all_features,
 			!self.no_default_features,
-		);
-		let opts = ResolveOpts::new(
-			/*dev_deps*/ true,
-			req,
-		);
+		)?;
 		let ws_resolve = cargo::ops::resolve_ws_with_opts(
 			&ws,
 			&target_data,
 			requested_kinds,
-			&opts,
+			&cli_features,
 			&Packages::All.to_package_id_specs(&ws)?,
 			HasDevUnits::Yes,
 			ForceAllTargets::No,
